@@ -1,17 +1,18 @@
-#!/usr/bin/env python2.6
+#!/usr/bin/env python2.7
 ################################################################################
 #
 #       This file is part of Gato (Graph Animation Toolbox) 
 #
 #	file:   Gato.py
-#	author: Alexander Schliep (alexander@schliep.org)
+#	author: Alexander Schliep (alexander@schlieplab.org)
 #
-#       Copyright (C) 1998-2015, Alexander Schliep, Winfried Hochstaettler and 
-#       Copyright 1998-2001 ZAIK/ZPR, Universitaet zu Koeln
+#       Copyright (C) 2016-2020 Alexander Schliep and
+#	Copyright (C) 1998-2015 Alexander Schliep, Winfried Hochstaettler and 
+#       Copyright (C) 1998-2001 ZAIK/ZPR, Universitaet zu Koeln
 #                                   
-#       Contact: alexander@schliep.org, winfried.hochstaettler@fernuni-hagen.de
+#       Contact: alexander@schlieplab.org
 #
-#       Information: http://gato.sf.net
+
 #
 #       This library is free software; you can redistribute it and/or
 #       modify it under the terms of the GNU Library General Public
@@ -30,8 +31,8 @@
 #
 #
 #
-#       This file is version $Revision: 670 $ 
-#                       from $Date: 2015-01-13 16:04:11 -0500 (Tue, 13 Jan 2015) $
+#       This file is version $Revision: 806 $ 
+#                       from $Date: 2020-12-08 15:13:58 +0100 (Tue, 08 Dec 2020) $
 #             last change by $Author: schliep $.
 #
 ################################################################################
@@ -52,6 +53,7 @@ import getopt
 
 import Gred
 
+
 from Tkinter import *
 from tkFileDialog import askopenfilename, asksaveasfilename
 from tkMessageBox import askokcancel, showerror, askyesno
@@ -67,6 +69,8 @@ import GatoIcons
 # Only needed for Trial-Solution version. 
 #import GatoSystemConfiguration
 from AnimationHistory import AnimationHistory, AnimationCommand
+import GatoExport
+
 
 # Workaround for bug in py2exe which mangles linecache on Windows
 # On Windows put a copy of linecache.py included in your Python's 
@@ -155,6 +159,7 @@ class AlgoWin(Frame):
         self.experimental = experimental
         if parent:
             parent.report_callback_exception = self.ReportCallbackException
+            self.parent = parent
         Frame.__init__(self,parent)
 
         #XXX import tkoptions
@@ -260,8 +265,13 @@ class AlgoWin(Frame):
         
         # --- FILE menu ----------------------------------------
         self.fileMenu = Menu(self.menubar, tearoff=0)
+        self.menubar.add_cascade(label="File", menu=self.fileMenu,
+                                 underline=0)
+
         self.fileMenu.add_command(label='Open Algorithm...',	
                                   command=self.OpenAlgorithm)
+        self.fileMenu.entryconfigure(1, state=DISABLED)
+        self.fileMenu.entryconfigure(1, state=ACTIVE)
         self.fileMenu.add_command(label='Open Graph...',	
                                   command=self.OpenGraph)
         # On the Mac starting gred from Gato will not create a seperate process
@@ -277,49 +287,78 @@ class AlgoWin(Frame):
         #			  command=self.SaveGatoFile)
         self.fileMenu.add_command(label='Reload Algorithm & Graph',	
                                   command=self.ReloadAlgorithmGraph)
-        self.fileMenu.add_command(label='Export Graph as EPS...',	
-                                  command=self.ExportEPSF)
 
-        if self.experimental:
-            self.fileMenu.add_command(label='Export Graph as SVG...',	
-                                      command=self.ExportSVG)
-            self.fileMenu.add_command(label='Export Animation as SVG...',	
-                                      command=self.ExportSVGAnimation)
+        self.fileMenu.add_separator()
+
+        self.fileMenu.add_command(label='Export Graph as SVG...',	
+                                  command=self.ExportGraphAsSVG)
+
+        #self.fileMenu.add_command(label='Export Graph as PNG...',	
+        #                          command=self.ExportGraphAsPNG)        
+
+        self.fileMenu.add_command(label='Export Graph as EPS...',	
+                                  command=self.ExportEPSF)        
+
+        self.fileMenu.add_separator()
+
+        self.fileMenu.add_command(label='Export Animation as HTML...',	
+                                  command=self.ExportHTMLAnimation)
+            
         if self.windowingsystem != 'aqua':
-            self.fileMenu.add_separator()
-            self.fileMenu.add_command(label='Preferences...',
-                                      command=self.Preferences,
-                                      accelerator='%s-,' % accMod)
+            #self.fileMenu.add_separator()
+            #self.fileMenu.add_command(label='Preferences...',
+            #                          command=self.Preferences,
+            #                          accelerator='%s-,' % accMod)
             #self.gatoInstaller.addMenuEntry(self.fileMenu)
             self.fileMenu.add_separator()
             self.fileMenu.add_command(label='Quit',		
                                       command=self.Quit,
                                       accelerator='%s-Q' % accMod)
-        self.menubar.add_cascade(label="File", menu=self.fileMenu, 
-                                 underline=0)	
-        # --- WINDOW menu ----------------------------------------
-        self.windowMenu=Menu(self.menubar, tearoff=0)
-        self.windowMenu.add_command(label='One graph window',	
-                                    accelerator='%s-1' % accMod,
-                                    command=self.OneGraphWindow)
-        self.windowMenu.add_command(label='Two graph windows',	
-                                    accelerator='%s-2' % accMod,
-                                    command=self.TwoGraphWindow)
-        self.menubar.add_cascade(label="Window Layout", menu=self.windowMenu, 
-                                 underline=0)
+
+        # --- WINDOW LAYOUT menu ----------------------------------------
+        if self.windowingsystem != 'aqua':                    
+            self.windowMenu=Menu(self.menubar, tearoff=0)
+            self.windowMenu.add_command(label='One graph window',	
+                                        accelerator='%s-1' % accMod,
+                                        command=self.OneGraphWindow)
+            self.windowMenu.add_command(label='Two graph windows',	
+                                        accelerator='%s-2' % accMod,
+                                        command=self.TwoGraphWindow)
+            self.menubar.add_cascade(label="Window Layout", menu=self.windowMenu, 
+                                     underline=0)
+
+        # --- AQUA Windows Menu
+        if self.windowingsystem == 'aqua':
+            self.aquawindowMenu = Menu(self.menubar, tearoff=0, name='window')
+            self.menubar.add_cascade(menu=self.aquawindowMenu, label='Window',
+                                     underline=0)
+            self.aquawindowMenu.add_separator()
+            self.aquawindowMenu.add_command(label='One graph window',
+                                            accelerator='%s-1' % accMod,
+                                            command=self.OneGraphWindow)
+            self.aquawindowMenu.add_command(label='Two graph windows',
+                                            accelerator='%s-2' % accMod,
+                                            command=self.TwoGraphWindow)
+
         
         
         # --- HELP menu ----------------------------------------
         self.helpMenu=Menu(self.menubar, tearoff=0, name='help')
-        
+        self.menubar.add_cascade(label="Help", menu=self.helpMenu,
+                                 underline=0)
+
         if self.windowingsystem != 'aqua':
             self.helpMenu.add_command(label='About Gato',
                                       command=self.AboutBox)
                                       
-        self.helpMenu.add_command(label='Help',
-                                  accelerator='%s-?' % accMod,
-                                  command=self.HelpBox)        
-        self.helpMenu.add_separator()
+            self.helpMenu.add_command(label='Help',
+                                      accelerator='%s-?' % accMod,
+                                      command=self.HelpBox)
+            
+            self.helpMenu.add_separator()
+        else:
+            self.parent.createcommand('tk::mac::ShowHelp', self.HelpBox)
+
         self.helpMenu.add_command(label='Go to Gato website',
                                   command=self.GoToGatoWebsite)
         self.helpMenu.add_command(label='Go to CATBox website',
@@ -329,21 +368,24 @@ class AlgoWin(Frame):
                                   command=self.AboutAlgorithm)
         self.helpMenu.add_command(label='About Graph',	
                                   command=self.AboutGraph)
-        self.menubar.add_cascade(label="Help", menu=self.helpMenu, 
-                                 underline=0)
+
 
 
         # --- MacOS X application menu --------------------------
         # On a Mac we put our about box under the Apple menu ... 
         if self.windowingsystem == 'aqua':
             self.apple=Menu(self.menubar, tearoff=0, name='apple')
-            self.apple.add_command(label='About Gato',	
-                                   command=self.AboutBox)
-            self.apple.add_separator()
-            self.apple.add_command(label='Preferences...',
-                                   accelerator='command-,',
-                                   command=self.Preferences)
-            self.menubar.add_cascade(menu=self.apple)
+            self.menubar.add_cascade(menu=self.apple, underline=0)
+            #self.apple.add_command(label='About My Application',	
+            #                       command=self.AboutBox)
+            #self.apple.add_separator()
+
+            self.parent.createcommand('tkAboutDialog', self.AboutBox)
+            self.parent.createcommand('tk::mac::ShowPreferences', self.Preferences)
+            #self.apple.add_command(label='Preferences...',
+            #                       accelerator='command-,',
+            #                       command=self.Preferences)
+            #self.menubar.add_cascade(menu=self.apple)
 
             
         self.master.configure(menu=self.menubar)
@@ -352,7 +394,7 @@ class AlgoWin(Frame):
     def makeToolBar(self):
         """ *Internal* Creates Start/Stop/COntinue ... toolbar """
         toolbar = Frame(self, cursor='hand2', relief=FLAT)
-        toolbar.pack(side=BOTTOM, fill=X) # Allows horizontal growth
+        toolbar.pack(side=BOTTOM, fill=X, padx=2, pady=2) # Allows horizontal growth
         toolbar.columnconfigure(5,weight=1)
         
         if os.name == 'nt' or os.name == 'dos':
@@ -426,7 +468,7 @@ class AlgoWin(Frame):
                                          )
         self.SetAlgorithmFont(self.algoFont, self.algoFontSize)
         self.algoText.pack(expand=1, fill=BOTH)
-        borderFrame.pack(side=TOP, expand=1, fill=BOTH)
+        borderFrame.pack(side=TOP, expand=1, fill=BOTH, padx=1, pady=1)
         
         # GUI-related tags
         self.algoText.tag_config('Interactive', foreground='#009900',background="#E5E5E5")
@@ -467,6 +509,15 @@ class AlgoWin(Frame):
                                  background=c('activebg'))
         g.BlinkRate = int(c('blinkrate'))
         g.BlinkRepeat = int(c('blinkrepeat'))
+
+
+    def HaveSecondaryGraphDisplay(self):
+        """ Returns true if there is a second graph displayed for current algorithm """
+        if not self.secondaryGraphDisplay or self.algorithm.graphDisplays == None or self.algorithm.graphDisplays == 1:
+            return False
+        else:
+            return True
+        
         
         
     def OpenSecondaryGraphDisplay(self):
@@ -624,7 +675,8 @@ class AlgoWin(Frame):
             
             if self.AboutAlgorithmDialog:
                 self.AboutAlgorithmDialog.Update(self.algorithm.About(),"About Algorithm")
-                
+
+               
     def NewGraph(self):
         Gred.Start()
         
@@ -841,49 +893,117 @@ class AlgoWin(Frame):
         if file is not "": 
             self.graphDisplay.PrintToPSFile(file)
 
-    def ExportSVG(self, fileName=None, write_to_png=False):
+    def GetSVGCoordinateDiff(self):
+        if  self.HaveSecondaryGraphDisplay():
+            return GatoExport.get_start_coordinate_diff(self.graphDisplay, self.secondaryGraphDisplay.animator)
+        else:
+            return GatoExport.get_start_coordinate_diff(self.graphDisplay)
+
+
+    def ExportGraphAsSVG(self):
         """ GUI to control export of SVG file  """
+        fileName = asksaveasfilename(title="Export SVG",
+                                     defaultextension=".svg",
+                                     filetypes = [("SVG", ".svg")]
+                                     )
+        if fileName is not "":
+            if self.HaveSecondaryGraphDisplay():
+                GatoExport.ExportGraphToSVG(fileName, self.algorithm, self.graphDisplayy, self.secondaryGraphDisplay)
+            else:
+                GatoExport.ExportGraphToSVG(fileName, self.algorithm, self.graphDisplay)
+
+                
+    def ExportSVG(self, fileName=None, write_to_png=False, start_graph_coord_diff=None):
+        """ *Obsolete*  """
         if not fileName:
             fileName = asksaveasfilename(title="Export SVG",
                                  defaultextension=".svg",
                                  filetypes = [("SVG", ".svg")]
                                  )
         if fileName is not "":
-            import GatoExport
-
-            if not self.secondaryGraphDisplay or self.algorithm.graphDisplays == None or self.algorithm.graphDisplays == 1:
-                return GatoExport.ExportSVG(fileName, self, self.algorithm, self.graphDisplay, 
-                    showAnimation=False, write_to_png=write_to_png)
-            else:
+            if self.HaveSecondaryGraphDisplay():
                 return GatoExport.ExportSVG(fileName, self, self.algorithm, self.graphDisplay,
-                    self.secondaryGraphDisplay.animator, showAnimation=False, write_to_png=write_to_png)
+                                            self.secondaryGraphDisplay.animator, showAnimation=False,
+                                            write_to_png=write_to_png, start_graph_coord_diff=start_graph_coord_diff,
+                                            restart_algorithm=False)
+            else:
+                return GatoExport.ExportSVG(fileName, self, self.algorithm, self.graphDisplay, 
+                                            showAnimation=False, write_to_png=write_to_png,
+                                            start_graph_coord_diff=start_graph_coord_diff,
+                                            restart_algorithm=False)
 
-    def ExportSVGAnimation(self, fileName=None, chapter_number=None, algo_div=None):
-        """ GUI to control export of SVG file  """
+            
+    def ExportSVGAnimation(self, fileName=None, chapter_number=None, algo_div=None, chapter_name=None):
+        """ Used to export animations from GatoTest  """
         if not fileName:
             fileName = asksaveasfilename(title="Export SVG",
                                          defaultextension=".svg",
                                          filetypes = [("SVG", ".svg")]
                                          )
         if fileName is not "":
-            import GatoExport
             # We never destroy the secondary graph display (and create it from the beginning
             # for the paned viewed. graphDisplays is set from prolog
-            if not self.secondaryGraphDisplay or self.algorithm.graphDisplays == None or self.algorithm.graphDisplays == 1:
-                GatoExport.ExportSVG(fileName, self, self.algorithm, self.graphDisplay, None, None, showAnimation=True, 
-                    init_edge_infos=self.algorithm.DB.init_edge_infos, init_vertex_infos=self.algorithm.DB.init_vertex_infos,
-                    init_graph_infos=self.algorithm.DB.init_graph_infos, chapter_number=chapter_number, algo_div=algo_div)
-            else:
+            if self.HaveSecondaryGraphDisplay():
                 GatoExport.ExportSVG(fileName, self, self.algorithm, self.graphDisplay,
                     self.secondaryGraphDisplay.animator, self.secondaryGraphDisplay, showAnimation=True,
                     init_edge_infos=self.algorithm.DB.init_edge_infos, init_vertex_infos=self.algorithm.DB.init_vertex_infos,
-                    init_graph_infos=self.algorithm.DB.init_graph_infos, chapter_number=chapter_number, algo_div=algo_div)
+                    init_graph_infos=self.algorithm.DB.init_graph_infos, chapter_number=chapter_number, algo_div=algo_div,
+                    chapter_name=chapter_name)
+            else:
+                GatoExport.ExportSVG(fileName, self, self.algorithm, self.graphDisplay, None, None, showAnimation=True, 
+                    init_edge_infos=self.algorithm.DB.init_edge_infos, init_vertex_infos=self.algorithm.DB.init_vertex_infos,
+                    init_graph_infos=self.algorithm.DB.init_graph_infos, chapter_number=chapter_number, algo_div=algo_div,
+                    chapter_name=chapter_name)
 
+
+                
+    def ExportHTMLAnimation(self):
+        """ GUI to control export of SVG file  """
+        chapter_number=None
+        algo_div=None
+        chapter_name=None
+        
+        graph_name = os.path.splitext(os.path.basename(self.algorithm.graphFileName))[0]
+        algo_name = os.path.splitext(os.path.basename(self.algorithm.algoFileName))[0]
+        
+        fileName = asksaveasfilename(title="Export HTML Animation",
+                                     defaultextension=".html",
+                                     filetypes = [("HTML", ".html")]
+                                     )
+        if fileName is not "":
+            fileBasename = os.path.splitext(os.path.basename(fileName))[0]
+            self.RunAlgorithmToCompletion()
+        
+            # We never destroy the secondary graph display (and create it from the beginning
+            # for the paned viewed. graphDisplays is set from prolog
+            if self.HaveSecondaryGraphDisplay():
+                GatoExport.ExportAnimationAsHTML(fileName, self, self.algorithm, self.graphDisplay,
+                                                 self.secondaryGraphDisplay.animator, self.secondaryGraphDisplay,
+                                                 init_edge_infos=self.algorithm.DB.init_edge_infos,
+                                                 init_vertex_infos=self.algorithm.DB.init_vertex_infos,
+                                                 init_graph_infos=self.algorithm.DB.init_graph_infos,
+                                                 chapter_number=None, algo_div=None,
+                                                 chapter_name=None, no_info_file=True,
+                                                 htmlTitle="%s: %s on graph %s" % (fileBasename, algo_name, graph_name),
+                                                 animationName="%s on graph %s" % (algo_name, graph_name))
+            else:
+                GatoExport.ExportAnimationAsHTML(fileName, self, self.algorithm, self.graphDisplay,
+                                                 None, None, 
+                                                 init_edge_infos=self.algorithm.DB.init_edge_infos,
+                                                 init_vertex_infos=self.algorithm.DB.init_vertex_infos,
+                                                 init_graph_infos=self.algorithm.DB.init_graph_infos,
+                                                 chapter_number=None, algo_div=algo_div,
+                                                 chapter_name=None, no_info_file=True,
+                                                 htmlTitle="%s: %s on graph %s" % (fileBasename, algo_name, graph_name),
+                                                 animationName="%s on graph %s" % (algo_name, graph_name))
+
+        
     def Quit(self,event=None):
         if self.algorithmIsRunning == 1:
             self.commandAfterStop = self.Quit
             self.CmdStop()
-            return
+            self.update_idletasks()
+            #return
             
         if askokcancel("Quit","Do you really want to quit?"):
             self.CleanUp()
@@ -1090,10 +1210,10 @@ class AlgoWin(Frame):
         widget.bind('c', self.KeyContinue)
         widget.bind('t', self.KeyTrace)
         widget.bind('b', self.KeyBreak)        
-        if self.experimental:
-            widget.bind('r', self.KeyReplay)
-            widget.bind('u', self.KeyUndo)
-            widget.bind('d', self.KeyDo)
+        #if self.experimental:
+        widget.bind('r', self.KeyReplay)
+        widget.bind('u', self.KeyUndo)
+        widget.bind('d', self.KeyDo)
         
         # Cross-plattform accelerators
         if self.windowingsystem == 'aqua':
@@ -1102,7 +1222,8 @@ class AlgoWin(Frame):
             accMod = "Control"
        
         widget.bind('<%s-q>' % accMod,  self.Quit)
-        widget.bind('<%s-comma>' % accMod,  self.Preferences)
+        if self.windowingsystem != 'aqua':
+            widget.bind('<%s-comma>' % accMod,  self.Preferences)
         widget.bind('<%s-KeyPress-1>' % accMod,  self.OneGraphWindow)
         widget.bind('<%s-KeyPress-2>' % accMod,  self.TwoGraphWindow)
         widget.bind('<%s-question>' % accMod,  self.HelpBox)
@@ -1174,6 +1295,7 @@ class AlgoWin(Frame):
         if self.lastActiveLine != 0:
             self.unTagLine(self.lastActiveLine,'Active')
         self.lastActiveLine = lineNo
+        log.debug("*ShowActive* %s" % lineNo)
         self.tagLine(lineNo,'Active')	
         self.algoText.yview_pickplace('%d.0' % lineNo)
         self.update() # Forcing redraw
@@ -1278,7 +1400,30 @@ class AlgoWin(Frame):
         self.lastActiveLine = 0
         self.codeLineHistory = []
 
-                
+    def RunAlgorithmToCompletion(self):
+        """ Utility function for exporting animations to HTML. Run algorithm without
+            user interaction until it completes.
+        """
+        oldGInteractive = g.Interactive
+        oldBreakpoints = self.algorithm.breakpoints
+        self.algorithm.breakpoints = []
+        g.Interactive = False
+        # Should restore breakpoints once we are done
+        self.algorithm.ClearBreakpoints()
+        self.algorithm.DB.alwaysTrace = 1 # Capture activeLine in sub-routines
+        self.update_idletasks()
+        self.update()
+        self.update_idletasks()
+        self.update()
+        # Run it ...
+        #self.after_idle(self.CmdContinue) # after idle needed since CmdStart
+        # does not return
+        self.CmdStart()
+        self.update_idletasks()
+        self.CmdContinue
+        g.Interactive = oldGInteractive
+        self.algorithm.breakpoint = oldBreakpoints
+        
 # Endof: AlgoWin ---------------------------------------------------------------
         
         
@@ -1293,6 +1438,7 @@ class AlgorithmDebugger(bdb.Bdb):
         self.GUI = dbgGUI
         bdb.Bdb.__init__(self)
         self.doTrace = 0
+        self.alwaysTrace = 0
         self.lastLine = -1
         self.init_edge_infos = [None, None]
         self.edge_infos = [None, None]
@@ -1309,6 +1455,7 @@ class AlgorithmDebugger(bdb.Bdb):
         if fn != self.GUI.algoFileName:
             return None
         line = self.currentLine(frame)
+        log.debug("dispatch_line %d (last %d)" % (line, self.lastLine))
         if line == self.lastLine:
             return self.trace_dispatch	    
         self.lastLine = line
@@ -1341,7 +1488,7 @@ class AlgorithmDebugger(bdb.Bdb):
             
         self.user_call(frame, arg)
         if self.quitting: raise bdb.BdbQuit
-        if doTrace == 1:
+        if doTrace == 1 or self.alwaysTrace:
             self.doTrace = 0
             return self.trace_dispatch
         if self.break_anywhere(frame):
@@ -1373,9 +1520,10 @@ class AlgorithmDebugger(bdb.Bdb):
         """ *Internal* Put debugger into initial state, calls forget() """
         bdb.Bdb.reset(self)
         self.forget()
-        
+        self.reset_component_infos()
         
     def forget(self):
+        self.lastLine = -1
         self.lineno = None
         self.stack = []
         self.curindex = 0
@@ -1392,7 +1540,7 @@ class AlgorithmDebugger(bdb.Bdb):
         """ *Internal* This function is called when we stop or break
             at this line """
         line = self.currentLine(frame)
-        #log.debug("*user_call* %s %s" % (line, argument_list))
+        log.debug("*user_call* %s %s" % (line, argument_list))
         if self.doTrace == 1:
             line = self.currentLine(frame)
             if line in self.GUI.breakpoints:
@@ -1408,10 +1556,12 @@ class AlgorithmDebugger(bdb.Bdb):
         #log.debug("%s" % inspect.getframeinfo(frame))
             
     def user_line(self, frame):
-        """ *Internal* This function is called when we stop or break at this line  """
+        """ *Internal* This function is called when we stop or break at this line
+            note: technically we stop at every line
+        """
         self.doTrace = 0 # XXX
         line = self.currentLine(frame)
-        # log.debug("*user_line* %s" % line)
+        log.debug("*user_line* %s" % line)
         if line in self.GUI.breakpoints:
             self.GUI.mode = 2
         self.GUI.GUI.ShowActive(line)
@@ -1437,6 +1587,14 @@ class AlgorithmDebugger(bdb.Bdb):
         #log.debug("exc_type_name: %s" repr.repr(exc_value))
         self.interaction(frame, exc_traceback)
       
+    def reset_component_infos(self):
+        self.init_edge_infos = [None, None]
+        self.edge_infos = [None, None]
+        self.init_vertex_infos = [None, None]
+        self.vertex_infos = [None, None]
+        self.init_graph_infos = [None, None]
+        self.graph_infos = [None, None]
+
     def add_info_commands_to_history(self):
         ''' Inspects the graphInformer of each graph display to look for changes to 
             the edge, graph, and vertex info.  If there are changes then we execute 
@@ -1562,17 +1720,22 @@ class AlgorithmDebugger(bdb.Bdb):
             
         self.forget()
         
-        
     def do_next(self):
         self.set_next(self.curframe)
         
     def do_quit(self):
         self.set_quit()
-        
+
+    def do_stop(self):
+        self.lastLine = -1
+ 
     def currentLine(self, frame):
         """ *Internal* returns the current line number  """ 
-        return frame.f_lineno 
-        
+        return frame.f_lineno
+
+    
+
+
 # Endof: AlgorithmDebugger  ----------------------------------------------------
         
 class Algorithm:
@@ -1586,6 +1749,7 @@ class Algorithm:
         self.breakpoints = []       # Doesnt debugger take care of it ?
         self.algoFileName = ""
         self.graphFileName = ""
+        self.graphDisplays = None
         self.mode = 0
         # mode = 0  Stop
         # mode = 1  Running
@@ -1811,7 +1975,7 @@ class Algorithm:
             for m in modules:
                 exec("from Gato.%s import *" % m, self.algoGlobals, self.algoGlobals)
             
-            
+
         # transfer required globals
         self.algoGlobals['gInteractive'] = g.Interactive
         # Read in prolog and execute it
@@ -1835,7 +1999,7 @@ class Algorithm:
             self.GUI.HandleError(short_msg, long_msg, log.exception)            
             self.GUI.CommitStop()
             return
-        
+
         if prologOnly:
             return
         # Read in algo and execute it in the debugger
@@ -1854,11 +2018,14 @@ class Algorithm:
             short_msg = "Error in %s.alg" % os.path.splitext(self.algoFileName)[0]
             long_msg = traceback.format_exc()
             self.GUI.HandleError(short_msg, long_msg, log.exception)            
-            
+        
+        self.GUI.graphDisplay.EndOfProlog()
+
         self.GUI.CommitStop()
         
     def Stop(self):
         self.mode = 0
+        self.DB.do_stop()
         
     def Step(self):
         if self.animation_history is not None:
@@ -2052,12 +2219,12 @@ def main(argv=None):
     if not argv: 
         argv = sys.argv    
     try:
-        opts, args = getopt.getopt(argv[1:], "pvdx", ["verbose","paned","debug","experimental"])
+        opts, args = getopt.getopt(argv[1:], "svdx", ["verbose","separate","debug","experimental"])
     except getopt.GetoptError:
         usage()
         return 2
 
-    paned = False
+    paned = True
     debug = False
     verbose = False        
     experimental = False
@@ -2075,8 +2242,9 @@ def main(argv=None):
                     logging.basicConfig(level=logging.DEBUG,
                                         stream=sys.stdout,
                                         format='%(name)s %(levelname)s %(message)s')
-            if o in ("-p", "--paned"):
-                paned = True
+            # Default is now paned view
+            if o in ("-s", "--separate"):
+                paned = False
             if o in ("-d", "--debug"):
                 debug = True
             if o in ("-x", "--experimental"):
@@ -2090,16 +2258,18 @@ def main(argv=None):
         except tkinter.TclError:
             pass
 
+        # NOTE: Options did caus menu items to display grayed out. Needed?
+        #
         #tk.option_add('*ActiveBackground','#EEEEEE')
-        tk.option_add('*background','#DDDDDD')
+        #tk.option_add('*background','#DDDDDD')
         #XXX Buttons look ugly with white backgrounds on MacOS X, added directly to Button(...)
         # The option not working is might be a known bug 
         # http://aspn.activestate.com/ASPN/Mail/Message/Tcl-bugs/2131881
         # Still present in the 8.4.7 that comes with 10.4  
-        tk.option_add('*Highlightbackground','#DDDDDD')
-        tk.option_add('*Button.highlightbackground','#DDDDDD')
-        tk.option_add('*Button.background','#DDDDDD')
-        tk.option_add('Tk*Scrollbar.troughColor','#CACACA')        
+        #tk.option_add('*Highlightbackground','#DDDDDD')
+        #tk.option_add('*Button.highlightbackground','#DDDDDD')
+        #tk.option_add('*Button.background','#DDDDDD')
+        #tk.option_add('Tk*Scrollbar.troughColor','#CACACA')        
 
         if paned:
             # We want a three paned left | right top / right bottom layout
@@ -2122,18 +2292,20 @@ def main(argv=None):
                 50))
             app.tkraise()
             app.master.update()            
+            app.update_idletasks()
             app.OneGraphWindow()
         else:
             app = AlgoWin(tk,experimental=experimental)
-            if debug:
-                app.algorithm.logAnimator = 2
+
+        if debug:
+            app.algorithm.logAnimator = 2
 
         # On MacOS X the Quit menu entry otherwise bypasses our Quit
         # Handler According to
         # http://mail.python.org/pipermail/pythonmac-sig/2006-May/017432.html
         # this should work
-        if not paned and app.windowingsystem == 'aqua':
-            tk.tk.createcommand("::tk::mac::Quit",app.Quit)
+        if app.windowingsystem == 'aqua':
+            tk.createcommand("::tk::mac::Quit",app.Quit)
             
         # XXX Here we should actually provide our own buffer and a Tk
         # Textbox to write to. NullHandler taken from
@@ -2170,6 +2342,22 @@ def main(argv=None):
             app.OpenGatoFile(fileName)
             app.update_idletasks()
             app.update()
+
+        if app.windowingsystem == 'aqua':
+            #app.master.iconify()
+            app.update()
+            app.master.deiconify()
+            app.master.lift()
+            # See discussion at https://stackoverflow.com/questions/1892339/how-to-make-a-tkinter-window-jump-to-the-front
+            if sys.argv[0] == 'Gato.py':
+                # If I am running from the command line the app is "Python"
+                os.system('''/usr/bin/osascript -e 'tell app "System Events" to set frontmost of process "Python" to true' ''')
+            else:
+                # When executing a packages MacOS App
+                # This does not throw an error, so I suppose sys.argv[0] is set correctly to Gato
+                # However this still asks the user for permision, which looks nefarious.
+                os.system('''/usr/bin/osascript -e 'tell app "System Events" to set frontmost of process "Gato" to true' ''')
+               
         app.mainloop()
     else:
         usage()
