@@ -4,13 +4,13 @@
 #       You can find more information at http://gato.sf.net
 #
 #	file:   GatoDialogs.py
-#	author: Alexander Schliep (alexander@schliep.org)
-#       Copyright (C) 1998-2015, Alexander Schliep, Winfried Hochstaettler and 
-#       Copyright 1998-2001 ZAIK/ZPR, Universitaet zu Koeln
+#	author: Alexander Schliep (alexander@schlieplab.org)
+#       Copyright (C) 2016-2020 Alexander Schliep and
+#	Copyright (C) 1998-2015 Alexander Schliep, Winfried Hochstaettler and 
+#       Copyright (C) 1998-2001 ZAIK/ZPR, Universitaet zu Koeln
 #                                   
-#       Contact: alexander@schliep.org, winfried.hochstaettler@fernuni-hagen.de             
+#       Contact: alexander@schlieplab.org             
 #
-#       Information: http://gato.sf.net
 #
 #       This library is free software; you can redistribute it and/or
 #       modify it under the terms of the GNU Library General Public
@@ -27,8 +27,8 @@
 #       Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 #
-#       This file is version $Revision: 670 $ 
-#                       from $Date: 2015-01-13 16:04:11 -0500 (Tue, 13 Jan 2015) $
+#       This file is version $Revision: 806 $ 
+#                       from $Date: 2020-12-08 15:13:58 +0100 (Tue, 08 Dec 2020) $
 #             last change by $Author: schliep $.
 #
 ################################################################################
@@ -45,20 +45,24 @@ import htmllib, formatter
 
 
 # Should be in GatoGlobals 
-crnotice1 = "Copyright (C) 1998-2015, Alexander Schliep\n"\
+crnotice1 = "Copyright (C) 2016-2020 Alexander Schliep.\n"\
+            "Copyright (C) 1998-2015 Alexander Schliep\n"\
             "and Winfried Hochstaettler. Copyright (C)\n"\
             "1998-2001 ZPR, University of Cologne\n"\
-            "Gato version %s from %s" % (GatoGlobals.gatoVersion,GatoGlobals.gatoBuildDate)
+            "Gato version %s from %s" % (GatoGlobals.gatoVersion,
+                                         GatoGlobals.gatoBuildDate)
 
-crnotice2 = "Written by Alexander Schliep (alexander@schliep.org).\n" \
+crnotice2 = "Written by Alexander Schliep (%s).\n" \
             "Application Design: Alexander Schliep and \n" \
             "Winfried Hochstaettler. Additional developers: Torsten\n" \
-            "Pattberg, Ramazan Buzdemir, Achim Gaedke,\n Janne Grunau and Wasinee Rungsarityotin.\n" \
+            "Pattberg, Ramazan Buzdemir, Achim Gaedke,\n" \
+            "Scott Merkling, Janne Grunau and Wasinee Rungsarityotin.\n" \
             "Screen Design: Heidrun Krimmel.\n\n" \
-            "For Information see http://gato.sf.net\n" \
+            "For Information see %s\n" \
             "Gato comes with ABSOLUTELY NO WARRANTY.\n" \
             "This is free software, and you are welcome to redistribute\n" \
-            "it under certain conditions. For details see 'LGPL.txt'.\n"
+            "it under certain conditions. For details see 'LGPL.txt'.\n" %(GatoGlobals.gatoAuthorEmail,
+                                                                           GatoGlobals.gatoURL)
 
 class AutoScrollbar(Scrollbar):
     """ Code taken from a comp.lang.python posting by
@@ -332,7 +336,7 @@ class HTMLViewer(Toplevel):
     def __init__(self, htmlcode, title, master=None):
     
         Toplevel.__init__(self, master)
-        #self.protocol('WM_DELETE_WINDOW',self.withdraw)
+        self.protocol('WM_DELETE_WINDOW',self.withdraw)
         self.titleprefix = title
         color = self.config("bg")[4]
         borderFrame = Frame(self, relief=SUNKEN, bd=2) # Extra Frame
