@@ -3,14 +3,14 @@
 #       This file is part of Gato (Graph Animation Toolbox)
 #
 #	file:   GatoGlobals.py
-#	author: Alexander Schliep (alexander@schliep.org)
+#	author: Alexander Schliep (alexander@schlieplab.org)
 #
-#       Copyright (C) 1998-2015, Alexander Schliep, Winfried Hochstaettler and 
-#       Copyright 1998-2001 ZAIK/ZPR, Universitaet zu Koeln
+#       Copyright (C) 2016-2020 Alexander Schliep and
+#	Copyright (C) 1998-2015 Alexander Schliep, Winfried Hochstaettler and 
+#       Copyright (C) 1998-2001 ZAIK/ZPR, Universitaet zu Koeln
 #                                   
-#       Contact: alexander@schliep.org, winfried.hochstaettler@fernuni-hagen.de             
+#       Contact: alexander@schlieplab.org             
 #
-#       Information: http://gato.sf.net
 #
 #       This library is free software; you can redistribute it and/or
 #       modify it under the terms of the GNU Library General Public
@@ -28,8 +28,8 @@
 #
 #
 #
-#       This file is version $Revision: 670 $ 
-#                       from $Date: 2015-01-13 16:04:11 -0500 (Tue, 13 Jan 2015) $
+#       This file is version $Revision: 806 $ 
+#                       from $Date: 2020-12-08 15:13:58 +0100 (Tue, 08 Dec 2020) $
 #             last change by $Author: schliep $.
 #
 #
@@ -37,8 +37,15 @@
 
 import tkFont
 
-gatoVersion = '1.2.2'
-gatoBuildDate = '1/13/2015'
+gatoVersion = '1.2.4'
+gatoBuildDate = '12/08/2020'
+gatoDescription = 'Graph Animation Toolbox: animating algorithms on graphs'
+gatoAuthorEmail = 'alexander@schlieplab.org'
+gatoURL = 'http://gato.sf.net'
+gatoDownloadURL = 'http://sourceforge.net/projects/gato/files/'
+gGatoURL = gatoURL
+gCATBoxURL = 'http://schliep.org/CATBox'
+
 
 class AnimationParameters:
     """ Convenience class to collect all globals. 
@@ -56,7 +63,7 @@ class AnimationParameters:
     FontSize = 10
     FontStyle = tkFont.BOLD
 
-    # Animation
+    # Animationk
     BlinkRate = 10 # ms
     BlinkRepeat = 3 # One more than you want
     Interactive = 1
@@ -68,11 +75,14 @@ class AnimationParameters:
     PaperHeight = 1500 # "20i" XXX Should be real paper size
     PaperWidth = 1500 # "20i"
 
+    # Other
+    GeneratingSVG = 0
+
     # Editing
     GridSize = 50 # Grid size for editor
 
     # Colors
-    cVertexDefault = "#000099" # 'red'
+    cVertexDefault = "#000099" # 'blue'
     cVertexBlink = "black"
     cEdgeDefault = "#DDDDDD" #"#EEEEEE"
     cEditorEdgeDefault = "#444444"
@@ -166,28 +176,30 @@ gProperty = {
     }
 
 
-gGatoURL = 'http://gato.sf.net'
-gCATBoxURL = 'http://schliep.org/CATBox'
-
 
 gGatoHelp = """
 <HTML>
 <HEAD><TITLE>Gato %s </TITLE></HEAD>
 <BODY>
+<img src="Icons/gato.gif">
 
 <H3>Keyboard Shortcuts</H3>
 
+<p>These shortcuts do not require any modifier (e.g., Ctrl, or Cmd) and are active at all times.
+The animation specific commands, r, u, d, only affect the animation, not the line. This is helpful to
+discuss specific steps in an algorithm.</p>
 <ul>
-<li> <tt>s</tt> Start
-<li> <tt>x</tt> Stop
-<li> <tt>[space]</tt> Step
-<li> <tt>c</tt> Continue
-<li> <tt>t</tt> trace
-<li> <tt>b</tt> toggle breakpoint
+<li> <tt>s</tt> Start the current algorithm.
+<li> <tt>x</tt> Stop the running algorithm.
+<li> <tt>[space]</tt> Step one command.
+<li> <tt>c</tt> Continue after a break.
+<li> <tt>t</tt> Trace into a function call.
+<li> <tt>b</tt> Toggle breakpoint on current line.
+<li> <tt>r</tt> Replay the last animation (will catch-up with all previously undone animation steps).
+<li> <tt>u</tt> Undo the last animation.
+<li> <tt>d</tt> (Re-)do the last undone animation.
 </ul>
 
-<img src="Icons/gato.gif">
-
 </BODY>
 </HTML>""" % gatoVersion
 
