@@ -3,14 +3,15 @@
 #       This file is part of Gato (Graph Animation Toolbox) 
 #
 #	file:   GraphDisplay.py
-#	author: Alexander Schliep (alexander@schliep.org)
+#	author: Alexander Schliep (alexander@schlieplab.org)
 #
-#       Copyright (C) 1998-2015, Alexander Schliep, Winfried Hochstaettler and 
-#       Copyright 1998-2001 ZAIK/ZPR, Universitaet zu Koeln
+#       Copyright (C) 2016-2020 Alexander Schliep and
+#	Copyright (C) 1998-2015 Alexander Schliep, Winfried Hochstaettler and 
+#       Copyright (C) 1998-2001 ZAIK/ZPR, Universitaet zu Koeln
 #                                   
-#       Contact: alexander@schliep.org, winfried.hochstaettler@fernuni-hagen.de
+#       Contact: alexander@schlieplab.org
 #
-#       Information: http://gato.sf.net
+
 #n
 #       This library is free software; you can redistribute it and/or
 #       modify it under the terms of the GNU Library General Public
@@ -28,8 +29,8 @@
 #
 #
 #
-#       This file is version $Revision: 670 $ 
-#                       from $Date: 2015-01-13 16:04:11 -0500 (Tue, 13 Jan 2015) $
+#       This file is version $Revision: 806 $ 
+#                       from $Date: 2020-12-08 15:13:58 +0100 (Tue, 08 Dec 2020) $
 #             last change by $Author: schliep $.
 #
 ################################################################################
@@ -118,6 +119,9 @@ class GraphDisplay(): #object): XXX New Style classes fuck up Tkinter
         self.zFontSize = g.FontSize
 
         self.g = g # So algorithms can get to the globals (XXX)
+
+        self.bubbles = {} # Mapping of vertex_list: (offset_value, color), used by WebGato
+        self.moats = {}   # Mapping of moat_id: (radius, color), used by WebGato
         
     def font(self, size):
         return tkFont.Font(self, (g.FontFamily, size, g.FontStyle))
@@ -370,6 +374,8 @@ class GraphDisplay(): #object): XXX New Style classes fuck up Tkinter
         self.drawLabel = VertexLabeling()
         self.vertexAnnotation = VertexLabeling()
         self.edgeAnnotation = EdgeLabeling()
+        self.bubbles = {}
+        self.moats = {}
         
         
     def DeleteDrawEdges(self):
@@ -1053,17 +1059,17 @@ class GraphDisplay(): #object): XXX New Style classes fuck up Tkinter
                 return None
 
     def CreateBubble(self, vertex_nums, offset_value, color):
-        pass
+        self.bubbles[vertex_nums] = (offset_value, color)
 
     def ResizeBubble(self, vertex_nums, new_radius):
         pass
 
     def DeleteBubble(self, vertex_nums):
-        pass
+        del self.bubbles[vertex_nums]
 
     def CreateMoat(self, moat_id, radius, color):
         # Moat ID is of form 'moat_{vertex_num}-{moat_num}'
-        pass
+        self.moats[moat_id] = (radius, color)
 
     def GrowMoat(self, moat_id, radius):
         pass
@@ -1071,6 +1077,9 @@ class GraphDisplay(): #object): XXX New Style classes fuck up Tkinter
     def Wait(self):
         pass
 
+    def EndOfProlog(self):
+        pass
+
     # XXX: Needs reorganisation. We could highlight paths, circuits
     # and vertex sets. Pretty (but not obvious) would be a convex
     # hull around a vertex set.
@@ -1245,15 +1254,15 @@ class GraphDisplay(): #object): XXX New Style classes fuck up Tkinter
         del(self.drawVertex.label[v])
         self.canvas.delete(self.drawLabel[v])
         del(self.drawLabel.label[v])
-        """ delete incident edges
+        # delete incident edges
         outVertices = self.G.OutNeighbors(v)[:] # Need a copy here
         inVertices = self.G.InNeighbors(v)[:]
-        #for w in outVertices:
-        #    self.DeleteEdge(v,w,0)
-        #for w in inVertices:
-        #    if w != v: # We have already deleted loops
+        for w in outVertices:
+            self.DeleteEdge(v,w,0)
+        for w in inVertices:
+            if w != v: # We have already deleted loops
                self.DeleteEdge(w,v,0)
-        """
+        
         self.G.DeleteVertex(v)
 
         
