@@ -1,4 +1,4 @@
-#!/usr/bin/env python2.6
+#!/usr/bin/env python2.7
 # -*- coding: utf-8 -*-
 ################################################################################
 #
@@ -7,12 +7,12 @@
 #	file:   setup-mac-gato.py
 #	author: Alexander Schliep
 #
-#       Copyright (C) 1998-2015, Alexander Schliep, Winfried Hochstaettler and 
-#       Copyright 1998-2001 ZAIK/ZPR, Universitaet zu Koeln
+#       Copyright (C) 2016-2020 Alexander Schliep and
+#	Copyright (C) 1998-2015 Alexander Schliep, Winfried Hochstaettler and 
+#       Copyright (C) 1998-2001 ZAIK/ZPR, Universitaet zu Koeln
 #                                   
-#       Contact: alexander@schliep.org, winfried.hochstaettler@fernuni-hagen.de
+#       Contact: alexander@schlieplab.org
 #
-#       Information: http://gato.sf.net
 #
 #       This library is free software; you can redistribute it and/or
 #       modify it under the terms of the GNU Library General Public
@@ -31,8 +31,8 @@
 #
 #
 #
-#       This file is version $Revision: 291 $ 
-#                       from $Date: 2006-10-18 16:04:35 +0200 (Wed, 18 Oct 2006) $
+#       This file is version $Revision: 806 $ 
+#                       from $Date: 2020-12-08 15:13:58 +0100 (Tue, 08 Dec 2020) $
 #             last change by $Author: schliep $.
 #
 ################################################################################
@@ -41,44 +41,30 @@
 #
 #
 #
+import distutils
+from distutils.core import setup
+import py2app
 
-from setuptools import setup
-#import distutils
-#from distutils.core import setup
+#from setuptools import setup
 
-long_description = """
-Gato, the Graph Animation Toolbox http://gato.sf.net by Alexander
-Schliep and Winfried Hochstaettler, is a LGPL-licensed Python
-application which animates algorithms on graphs. It uses Tkinter and
-runs on Unix, MacOS X, Linux and Windows.
+# Read info from GatoGlobals.py ... the following code makes sure we read
+# GatoGlobals.py in the current directory
+import sys
+if sys.version_info < (3,0):
+    info={}
+    execfile("GatoGlobals.py", info)
+else:
+    # Some variant of exec(open("GatoGlobals.py").read())
+    raise NotImplementedError
 
-It is primarily a teaching tool, but can also be useful in research on
-algorithm design and engineering, for example by demonstrating effects of
-heuristics.
-
-It is used in CATBox (Springer 2010, see authors' website
-http://schliep.org/CATBox) by Winfried Hochstaettler and Alexander
-Schliep. CATBox is a textbook on combinatorial optimization on graphs
-(traversals, minimal spanning trees, shortest paths, maximum flows,
-min-cost flows, cardinality and weighted matching) which uses Gato to
-provide interactive animations and exercises for all algorithms.  A
-screencast is at:
-http://biomaps.rutgers.edu/~schliep/CATBox/Dijkstra.swf
-
-Gato and CATBox has been used in university classrooms for several
-years by us and colleagues on several continents at the undergraduate
-and graduate level.  Winfried Hochstaettler is a professor in
-mathematics at the FernUniversitaet Hagen, Germany and Alexander
-Schliep is an associate professor in computer science and quantitative
-biology at Rutgers University.
-"""
+long_description_text = open('README').readlines()
 
 
 
 setup(name="Gred",
       app=['Gred.py'],
-      version="1.2.2",
-      setup_requires=["py2app"],
+      version=info['gatoVersion'],
+      #setup_requires=["py2app"],
       options=dict(py2app=dict(semi_standalone=None,
                                argv_emulation=True,
                                iconfile='Gred.icns',
@@ -108,17 +94,17 @@ setup(name="Gred",
                                plist=dict(CFBundleIdentifier='org.schliep.gred',
                                           CFBundleGetInfoString='Graph Animation Toolbox',
                                           NSHumanReadableCopyright= \
-                                          u"\u00A9 Alexander Schliep and Winfried Hochst\u00E4ttler 2014")
+                                          u"\u00A9 Alexander Schliep 2020")
                                )
                                ),
-      description="Graph Animation Toolbox: animating algorithms on graphs",
-      long_description = long_description,
-      author="Alexander Schliep and Winfried Hochstaettler",
-      author_email="alexander@schliep.org",
-      maintainer="Alexander Schliep",
-      maintainer_email="alexander@schliep.org",
-      url="http://gato.sf.net/",
-      download_url = 'http://sourceforge.net/projects/gato/files/',
+      description = info['gatoDescription'],
+      long_description = long_description_text,
+      author = "Alexander Schliep and Winfried Hochstaettler",
+      author_email = info['gatoAuthorEmail'],
+      maintainer = "Alexander Schliep",
+      maintainer_email = info['gatoAuthorEmail'],
+      url = info['gatoURL'],
+      download_url = info['gatoDownloadURL'],
       packages=['Gato'],
       package_dir={'Gato': ''},
       #scripts=['scripts/Gato', 'scripts/Gred'],
@@ -133,7 +119,6 @@ setup(name="Gred",
                    'Operating System :: MacOS :: MacOS X',
                    'Operating System :: Microsoft :: Windows',
                    'Operating System :: POSIX',
-                   'Programming Language :: Python :: 2.6',
                    'Programming Language :: Python :: 2.7',
                    'Topic :: Education',
                    'Topic :: Education :: Computer Aided Instruction (CAI)',
